@@ -5,14 +5,14 @@ to make your development life easier by creating everything that’s necessary t
 start working on a particular task.
 
 Each generator is build of the following:
-    * A cookiecutter template.
+    * A copier template.
     * Click options and arguments for creating generator CLI subcommand.
-    * Methods for creating and deleting the thing it generates.
+    * Method for creating thing it generates.
 
 Resources:
     1. `Click Arguments`_
     2. `Click Options`_
-    3. `Cookiecutter Docs`_
+    3. `Copier Docs`_
 
 .. _Click Arguments:
     https://click.palletsprojects.com/en/8.1.x/arguments/
@@ -20,19 +20,13 @@ Resources:
 .. _Click Options:
     https://click.palletsprojects.com/en/8.1.x/options/
 
-.. _Cookiecutter Docs:
-    https://cookiecutter.readthedocs.io/en/1.7.2/
+.. _Copier Docs:
+    https://copier.readthedocs.io/en/v6.2.0
 
 """
-from fastapi_mvc.generators.base import Generator
-from fastapi_mvc.generators.project import ProjectGenerator
-from fastapi_mvc.generators.controller import ControllerGenerator
-from fastapi_mvc.generators.generator import GeneratorGenerator
+from fastapi_mvc.generators.loader import load_generators
+from fastapi_mvc.generators.generator import generator
+from fastapi_mvc.generators.controller import controller
 
 
-__all__ = (
-    "Generator",
-    "ProjectGenerator",
-    "ControllerGenerator",
-    "GeneratorGenerator",
-)
+__all__ = ("load_generators", "controller", "generator")
